==> freedroidrpg-1.0rc2-1-x86_64.pkg.tar.zst: usr/share/freedroidrpg/data/base/titles/cs/Controls.lua <==
---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            OVLÁDÁNÍ

POHYB:

Hra se ovládá pomocí myši. Klikněte levým tlačítkem na místa, do nichž se chcete přesunout. Podržte tlačítko, aby jste se pohybovali tímto směrem. Držením klávesnice CTRL budete utíkat.

ÚTOK:

Klikání levým tlačítkem myši na nepřítele způsobí, že se Tux přiblíží k robotovi a začne útočit s aktuální zbraní. Pokud je aktuální zbraní pistole, pak bude Tux stát na místě a střílet na robota.

SPECIÁLNÍ FUNKCE:

Použijte pravé tlačítko myši pro aktivaci aktuálně vybrané dovednosti/programu.

Výchozí klávesy (většina kláves může být přeřazena pomocí přehledu kláves v průběhu hry - F1)

  Klávesa ESC ... zobrazí hlavní menu
  F1 ... Přehled klávesových zkratek
  F2 ... Přepínání celé obrazovky (pouze Linux)
  F3 ... Rychlé uložení
  F4 ... Rychlé nahrání
  F5-F12 ... Rychlý výběr programu od 1 do 8

  I ... Panel inventáře
  C ... Panel postavy
  S ... Panel dovedností/programů
  Mezerník ... Zavře všechny otevřené panely
  Q ... Přehled úkolů
  0-9 ... Rychlé použití položek 0-9 z inventáře

  P ... Pauza
  Drž A ... Útok při zachování stejné pozice
  Drž Shift ... Aktuální cíl zůstane při pohybu vybrán
  Tab ... Přepínání automapy

  R ... Nabít zbraň
  Drž CTRL ... Běh
  U ... Přepínání běhu a chůze

  Drž X ... Zobraz názvy předmětů na zemi
  Z ... Přepínání zobrazení názvů předmětů na zemi
  T ... Přepínání průhlednost zdí, kde Tux prochází (pouze OpenGL)

PŘEVZETÍ/CHAT

Chcete-li konverzovat s přátelským droidem, stačí, abyste na něj klikli. Pro převzetí vlády nad nepřátelským robotem vyberte dovednost převzetí/chat z panelu dovedností, pak klepněte pravým tlačítkem myši pro zahájení převzetí.

V průběhu hry převzetí lze použít kolečko myši nebo kurzorová tlačítka.

Možná vás bude zajímat výuková hra, která je přístupná z hlavního menu.

Pokud jste se zasekli a potřebujete pomoc, neváhejte přijít na #freedroid na irc.freenode.net a požádejte o pomoc.

To je vše, užijte si hru.



Stiskem levého tlačítka myši začněte hrát.
]]
}

==> freedroidrpg-1.0-4-x86_64.pkg.tar.zst: usr/share/freedroidrpg/data/base/titles/cs/Controls.lua <==
---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            OVLÁDÁNÍ

POHYB:

Hra se ovládá pomocí myši. Klikněte levým tlačítkem na místo, do něhož se chcete přesunout. Podržte tlačítko, aby jste se pohybovali tímto směrem. Podržením klávesnice CTRL budete utíkat.

ÚTOK:

Klikáním levého tlačítka myši na nepřítele se Tux přiblíží k robotovi a začne útočit s aktuální zbraní. Pokud je aktuální zbraní pistole, pak bude Tux stát na místě a střílet na robota.

SPECIÁLNÍ FUNKCE:

Použijte pravé tlačítko myši pro aktivaci aktuálně vybrané dovednosti/programu.

Výchozí klávesy (většina kláves může být přeřazena pomocí přehledu kláves v průběhu hry - F1)

  Klávesa ESC ... zobrazí hlavní menu
  F1 ... Přehled klávesových zkratek
  F2 ... Přepínání celé obrazovky (pouze Linux)
  F3 ... Rychlé uložení
  F4 ... Rychlé nahrání
  F5-F12 ... Rychlý výběr programu od 1 do 8

  I ... Panel inventáře
  C ... Panel postavy
  S ... Panel dovedností/programů
  Mezerník ... Zavře všechny otevřené panely
  Q ... Přehled úkolů
  0-9 ... Rychlé použití položek 0-9 z inventáře

  P ... Pauza
  Drž A ... Útok při zachování stejné pozice
  Drž Shift ... Aktuální cíl zůstane při pohybu vybrán
  Tab ... Přepínání automapy

  R ... Nabít zbraň
  Drž CTRL ... Běh
  U ... Přepínání běhu a chůze

  Drž X ... Zobraz názvy předmětů na zemi
  Z ... Přepínání zobrazení názvů předmětů na zemi
  T ... Přepínání průhlednost zdí, kde Tux prochází (pouze OpenGL)

PŘEVZETÍ/CHAT

Chcete-li hovořit s přátelským droidem, stačí, abyste na něj klikli. Pro převzetí vlády nad nepřátelským robotem vyberte dovednost převzetí/chat z panelu dovedností, pak klepněte pravým tlačítkem myši pro zahájení převzetí.

Při průběhu minihry o převzetí robota lze používat kolečko myši nebo kurzorová tlačítka.

Možná vás bude zajímat výuková hra, která je přístupná z hlavního menu.

Pokud jste uvízli a potřebujete pomoc, neváhejte a přijďte na #freedroid na irc.libera.chat a požádejte o pomoc.

To je vše, užijte si hru.



Stiskem levého tlačítka myši začněte hrát.
]]
}
